<?php
// File: chat.php

session_start();

// Ensure user is logged in
if (!isset($_SESSION['username'])) {
    header('Location: user_login.php');
    exit;
}

$username = $_SESSION['username'];
$online_users_file = 'online_users.txt';

// Get the list of online users, excluding the current user
function getOnlineUsers($file, $current_user) {
    $users = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    return array_filter($users, fn($user) => trim($user) !== $current_user);
}

$online_users = getOnlineUsers($online_users_file, $username);

// Handle chat initiation
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $recipient = $_POST['recipient'];
    if ($recipient) {
        $_SESSION['chat_with'] = $recipient;
        header('Location: private_chat.php');
        exit;
    }
}

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Chat Selection</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f3f4f6;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .container {
            background: #ffffff;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            text-align: center;
            width: 300px;
        }

        h1 {
            margin: 0 0 10px;
            font-size: 24px;
            color: #333;
        }

        h2 {
            font-size: 18px;
            color: #555;
            margin-bottom: 20px;
        }

        select, button {
            font-size: 16px;
            padding: 10px;
            margin: 10px 0;
            border-radius: 5px;
            border: 1px solid #ccc;
            width: 100%;
            box-sizing: border-box;
        }

        button {
            background-color: #4a76a8;
            color: #ffffff;
            border: none;
            cursor: pointer;
        }

        button:hover {
            background-color: #3c5e8b;
        }

        a {
            display: inline-block;
            margin-top: 20px;
            color: #4a76a8;
            text-decoration: none;
            font-size: 14px;
        }

        a:hover {
            text-decoration: underline;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Welcome, <?= htmlspecialchars($username) ?></h1>
        <h2>Select a user to chat with:</h2>

        <?php if (empty($online_users)): ?>
            <p>No other users are online right now.</p>
        <?php else: ?>
            <form method="POST" action="">
                <select name="recipient" required>
                    <?php foreach ($online_users as $user): ?>
                        <option value="<?= htmlspecialchars($user) ?>">
                            <?= htmlspecialchars($user) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
                <button type="submit">Start Chat</button>
            </form>
        <?php endif; ?>

        <a href="logout.php">Logout</a>
    </div>
</body>
</html>
