<?php
// File: user_login.php

session_start();

// Simulated database (can be replaced with an actual database or file storage)
$users_file = 'users.txt';
$online_users_file = 'online_users.txt';

// Function to get all users from the file
function getUsers($file) {
    if (!file_exists($file)) return [];
    $users = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    return $users ? array_map('trim', $users) : [];
}

// Function to save a user to a file
function saveUser($file, $user) {
    $users = getUsers($file);
    if (!in_array($user, $users)) {
        file_put_contents($file, $user . "\n", FILE_APPEND);
    }
}

// Variables for messages
$confirmationMessage = "";
$errorMessage = "";
$username = "";

// Handle registration or login
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = trim($_POST['username']);

    if (isset($_POST['confirmUsername'])) {
        // User confirmed
        $username = $_POST['confirmUsername'];
        saveUser($online_users_file, $username);
        $_SESSION['username'] = $username;
        header('Location: chat.php');
        exit;
    }

    if (!$username) {
        $errorMessage = "Il nome utente è richiesto.";
    } else {
        $users = getUsers($users_file);
        if (in_array($username, $users)) {
            $confirmationMessage = "Il nome utente '<strong>" . htmlspecialchars($username) . "</strong>' è già registrato. Vuoi continuare come '<strong>" . htmlspecialchars($username) . "</strong>'?";
        } else {
            saveUser($users_file, $username);
            saveUser($online_users_file, $username);
            $_SESSION['username'] = $username;
            header('Location: chat.php');
            exit;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registrati</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f8f9fa;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
        }

        .container {
            background: #ffffff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
            width: 400px;
            text-align: center;
        }

        h1 {
            font-size: 24px;
            color: #333;
            margin-bottom: 20px;
        }

        .confirmation {
            font-size: 16px;
            color: #555;
            margin-bottom: 20px;
        }

        .error {
            font-size: 16px;
            color: red;
            margin-bottom: 20px;
        }

        .button-container {
            display: flex;
            justify-content: space-between;
            margin-top: 20px;
        }

        button {
            padding: 10px 20px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
            font-weight: bold;
            flex: 1;
            margin: 0 5px;
        }

        .confirm {
            background-color: #28a745;
            color: #ffffff;
        }

        .confirm:hover {
            background-color: #218838;
        }

        .register {
            background-color: #007bff;
            color: #ffffff;
        }

        .register:hover {
            background-color: #0056b3;
        }

        input[type="text"] {
            width: 100%;
            padding: 12px;
            margin-bottom: 20px;
            border: 1px solid #ccc;
            border-radius: 5px;
            box-sizing: border-box;
            font-size: 16px;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Registrati</h1>
        <?php if (!empty($confirmationMessage)): ?>
            <div class="confirmation"><?php echo $confirmationMessage; ?></div>
            <form method="POST">
                <input type="hidden" name="confirmUsername" value="<?php echo htmlspecialchars($username); ?>">
                <div class="button-container">
                    <button type="submit" class="confirm">Sì, continua</button>
                    <button type="button" class="register" onclick="window.location.href='user_login.php'">No, torna indietro</button>
                </div>
            </form>
        <?php else: ?>
            <?php if (!empty($errorMessage)): ?>
                <div class="error"><?php echo $errorMessage; ?></div>
            <?php endif; ?>
            <form method="POST">
                <label for="username">Inserisci il tuo nome utente:</label>
                <input type="text" id="username" name="username" required placeholder="Nome utente">
                <div class="button-container">
                    <button type="submit" class="register">Registrati</button>
                </div>
            </form>
        <?php endif; ?>
    </div>
</body>
</html>
